@@ -3,36 +3,32 @@
 // Purpose:     
 // Author:      Alex Thuering
 // Created:     15/01/2005
-// RCS-ID:      $Id: svgview.cpp,v 1.14 2012/04/01 20:37:00 ntalex Exp $
+// RCS-ID:      $Id: svgview.cpp,v 1.16 2015/03/21 19:27:52 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     wxWindows licence
 //////////////////////////////////////////////////////////////////////////////
 
-#if defined(__GNUG__) && !defined(__APPLE__)
-#pragma implementation
-#pragma interface
-#endif
-
-// For compilers that support precompilation, includes "wx.h".
-#include "wx/wxprec.h"
-
-#ifdef __BORLANDC__
-#pragma hdrstop
-#endif
-
-#ifndef WX_PRECOMP
-#include "wx/wx.h"
-#endif
-
-#ifndef __WXWINCE__
-#include <locale.h>
-#endif
-
 #include "svgview.h"
+#include "wx/wx.h"
+#include <wx/mstream.h>
 #include <wxSVG/svg.h>
 #ifdef USE_LIBAV
 #include <wxSVG/mediadec_ffmpeg.h>
 #endif
+#include "wxsvg.png.h"
+
+#define wxICON_FROM_MEMORY(name) wxGetIconFromMemory(name##_png, sizeof(name##_png))
+
+inline wxBitmap wxGetBitmapFromMemory(const unsigned char *data, int length) {
+   wxMemoryInputStream is(data, length);
+   return wxBitmap(wxImage(is, wxBITMAP_TYPE_ANY, -1), -1);
+}
+
+inline wxIcon wxGetIconFromMemory(const unsigned char *data, int length) {
+   wxIcon icon;
+   icon.CopyFromBitmap(wxGetBitmapFromMemory(data, length));
+   return icon;
+}
 
 //////////////////////////////////////////////////////////////////////////////
 ///////////////////////////////  Application /////////////////////////////////
@@ -40,8 +36,8 @@
 
 IMPLEMENT_APP(SVGViewApp)
 
-bool SVGViewApp::OnInit()
-{
+bool SVGViewApp::OnInit() {
+	wxGetApp();
 #ifndef __WXWINCE__
   setlocale(LC_NUMERIC, "C");
 #endif
@@ -51,8 +47,9 @@ bool SVGViewApp::OnInit()
   wxFfmpegMediaDecoder::Init();
 #endif
   
-  new MainFrame(NULL, wxT("SVG Viewer"),
-    wxDefaultPosition, wxSize(500, 400));
+  MainFrame* mainFrame = new MainFrame(NULL, wxT("SVG Viewer"), wxDefaultPosition, wxSize(500, 400));
+  SetTopWindow(mainFrame);
+  
   return true;
 }
 
@@ -94,6 +91,12 @@ MainFrame::MainFrame(wxWindow *parent, const wxString& title, const wxPoint& pos
     menuBar->Append(fileMenu, _T("&File"));
     SetMenuBar(menuBar);
 
+#ifndef __WXMSW__
+	SetIcon(wxICON_FROM_MEMORY(wxsvg));
+#else
+	SetIcon(wxICON(wxsvg));
+#endif
+
     m_svgCtrl = new MySVGCanvas(this);
     if (wxTheApp->argc > 1)
       m_svgCtrl->Load(wxTheApp->argv[1]);
